==> library1.4.1.tar.bz2: library/cicl/book-add-frm.php <==
<?php
  ///////////////////////////////////////////////////
  //2011 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['search-alf-book'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

if(strlen($_GET['cicle_id'])>5) {puterror($result2['skin'],$TEXT['error-cicle6']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['cicle_id'] = rep($_GET['cicle_id']);
if(strlen($_GET['k'])>8) {puterror($result2['skin'],$TEXT['error-paging1']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_GET['bukva'])>4) {puterror($result2['skin'],$TEXT['error-bukva']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['bukva'] = rep($_GET['bukva']);
$_GET['k'] = rep($_GET['k']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;
$old_ccl = $_GET['cicle_id'];

if(empty($_GET['bukva']))
 {
  if(empty($_POST['bukva'])) {$bukva = "А";}
   else {$bukva = $_POST['bukva'];}
} else {$bukva = $_GET['bukva'];}
?>
<table align="center" border="0" cellpadding="0" cellspacing="0" width="95%">
<tr>
<td align="center">
<?php
    $query_body1 = "SELECT DISTINCT first_bt AS bukva FROM `tbl_book` ORDER BY bukva ";
     $result_body1 = mysqli_query($dbcnx,$query_body1);
     if(!$result_body1) {puterror($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}
       while($result_body_autor1 = mysqli_fetch_array($result_body1))
        {
        if($bukva == $result_body_autor1['bukva']) {echo "&nbsp;<a class='zagolovok' href=book-add-frm.php?bukva=".$result_body_autor1['bukva']." title='".$TEXT['alfbook-title'].$result_body_autor1['bukva']."'>".$result_body_autor1['bukva']."</a>";}
         else {echo "&nbsp;<a href=book-add-frm.php?bukva=".$result_body_autor1['bukva']."&amp;cicle_id=".$old_ccl." title='".$TEXT['alfbook-title'].$result_body_autor1['bukva']."'>".$result_body_autor1['bukva']."</a>";}
        }
?>
</td>
</tr>
</table>
<hr width="70%" />
<table align="center" border="0" cellpadding="3" cellspacing="0" width="90%">
<tbody id="tab" >
<?php
     $query_body2 = "SELECT cicle_id FROM `tbl_cicle` WHERE cicle = '---' ";
     $result_body2 = mysqli_query($dbcnx,$query_body2);
     if(!$result_body2) {puterror($result2['skin'],$TEXT['error-tbl5']); require_once "../utils/bottom_adm.php"; exit();}
      $result_body_cicle1 = mysqli_fetch_array($result_body2);
      $ccl = $result_body_cicle1['cicle_id'];

     $query_body = "SELECT book_name, book_id, vidano
     FROM tbl_book
     WHERE first_bt = '".$bukva."' AND cicle_id = ".$ccl."
     ORDER BY book_name
     LIMIT $lim_ogr";
     $result_body = mysqli_query($dbcnx,$query_body);
     if(!$result_body) {puterror2($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}
       $result_rows = mysqli_num_rows($result_body);
       if($result_rows > 0)
         {
          while($result_body_book= mysqli_fetch_array($result_body))
               {
               if($result_body_book['vidano'] == '3') {$book_name = "<a href=info.php?book_id=".$result_body_book['book_id']." title='".$TEXT['aut-viewtit']."'><span class='zagolovok_zak'>".$result_body_book['book_name']."</span></a>";}
                elseif($result_body_book['vidano'] == '2') {$book_name = "<a href=info.php?book_id=".$result_body_book['book_id']." title='".$TEXT['aut-viewtit']."'><span class='zagolovok_sp'>".$result_body_book['book_name']."</span></a>";}
                elseif($result_body_book['vidano'] == '1') {$book_name = "<a href=info.php?book_id=".$result_body_book['book_id']." title='".$TEXT['aut-viewtit']."'><span class='zagolovok_vid'>".$result_body_book['book_name']."</span></a>";}
               else {$book_name = "<a href=../info.php?book_id=".$result_body_book['book_id']." target=_blank title='".$TEXT['aut-viewtit']."'><span class='zagolovok'>".$result_body_book['book_name']."</span></a>&nbsp;&nbsp;<a href=book-add-ccl.php?book_id=".$result_body_book['book_id']."&amp;cicle_id=".$old_ccl." title='".$TEXT['add-new']."'><img alt='".$TEXT['add-new']."' src='../skins/".$result2['skin']."/add.png' /></a>";}
               
               echo "<tr>";
               echo "<td colspan='2' align= 'center' width='50%'>".$book_name."</td>";
               echo "</tr>";
             }
         }
?>
</tbody>
</table>
     <?php
       $query_count = mysqli_query($dbcnx,"SELECT COUNT(book_id) AS c_book_id FROM tbl_book WHERE `first_bt` = '".$_GET['bukva']."' AND cicle_id = ".$ccl."");
	       $coun_rows = mysqli_fetch_array($query_count);
               $pag = $coun_rows['c_book_id']/10;
               if($pag<=1) {$pag = ceil($pag);}
                else
                {
                 ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='book-add-frm.php?k=".$k."&amp;bukva=".$_GET['bukva']."&amp;cicle_id=".$old_ccl."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='book-add-frm.php?k=".$k."&amp;bukva=".$_GET['bukva']."&amp;cicle_id=".$old_ccl."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=book-add-frm.php?k=".$k."&amp;bukva=".$_GET['bukva']."&amp;cicle_id=".$old_ccl.">".$j."</option>";}
                       else {echo "<option value=book-add-frm.php?k=".$k."&amp;bukva=".$_GET['bukva']."&amp;cicle_id=".$old_ccl.">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>
                 <?php
                }
require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/cicl/book-add-frm.php <==
<?php
  ///////////////////////////////////////////////////
  //2011 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['search-alf-book'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

if(strlen($_GET['cicle_id'])>5) {puterror($result2['skin'],$TEXT['error-cicle6']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['cicle_id'] = rep($_GET['cicle_id']);
if(strlen($_GET['k'])>8) {puterror($result2['skin'],$TEXT['error-paging1']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_GET['bukva'])>4) {puterror($result2['skin'],$TEXT['error-bukva']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['bukva'] = rep($_GET['bukva']);
$_GET['k'] = rep($_GET['k']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;
$old_ccl = $_GET['cicle_id'];

if(empty($_GET['bukva']))
 {
  if(empty($_POST['bukva'])) {$bukva = "А";}
   else {$bukva = $_POST['bukva'];}
} else {$bukva = $_GET['bukva'];}
?>
<table align="center" border="0" cellpadding="0" cellspacing="0" width="95%">
<tr>
<td align="center">
<?php
    $query_body1 = "SELECT DISTINCT first_bt AS bukva FROM `tbl_book` ORDER BY bukva ";
     $result_body1 = mysqli_query($dbcnx,$query_body1);
     if(!$result_body1) {puterror($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}
       while($result_body_autor1 = mysqli_fetch_array($result_body1))
        {
        if($bukva == $result_body_autor1['bukva']) {echo "&nbsp;<a class='zagolovok' href='book-add-frm.php?bukva=".$result_body_autor1['bukva']."' title='".$TEXT['alfbook-title'].$result_body_autor1['bukva']."'>".$result_body_autor1['bukva']."</a>";}
         else {echo "&nbsp;<a href='book-add-frm.php?bukva=".$result_body_autor1['bukva']."&amp;cicle_id=".$old_ccl."' title='".$TEXT['alfbook-title'].$result_body_autor1['bukva']."'>".$result_body_autor1['bukva']."</a>";}
        }
?>
</td>
</tr>
</table>
<hr width="70%" />
<table align="center" border="0" cellpadding="3" cellspacing="0" width="90%">
<tbody id="tab" >
<?php
     $query_body2 = "SELECT cicle_id FROM `tbl_cicle` WHERE cicle = '---' ";
     $result_body2 = mysqli_query($dbcnx,$query_body2);
     if(!$result_body2) {puterror($result2['skin'],$TEXT['error-tbl5']); require_once "../utils/bottom_adm.php"; exit();}
      $result_body_cicle1 = mysqli_fetch_array($result_body2);
      $ccl = $result_body_cicle1['cicle_id'];

     $query_body = "SELECT book_name, book_id, vidano
     FROM tbl_book
     WHERE first_bt = '".$bukva."' AND cicle_id = ".$ccl."
     ORDER BY book_name
     LIMIT $lim_ogr";
     $result_body = mysqli_query($dbcnx,$query_body);
     if(!$result_body) {puterror2($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}
       $result_rows = mysqli_num_rows($result_body);
       if($result_rows > 0)
         {
          while($result_body_book= mysqli_fetch_array($result_body))
               {
               if($result_body_book['vidano'] == '3') {$book_name = "<a href='info.php?book_id=".$result_body_book['book_id']."' title='".$TEXT['aut-viewtit']."'><span class='zagolovok_zak'>".$result_body_book['book_name']."</span></a>";}
                elseif($result_body_book['vidano'] == '2') {$book_name = "<a href='info.php?book_id=".$result_body_book['book_id']."' title='".$TEXT['aut-viewtit']."'><span class='zagolovok_sp'>".$result_body_book['book_name']."</span></a>";}
                elseif($result_body_book['vidano'] == '1') {$book_name = "<a href='info.php?book_id=".$result_body_book['book_id']."' title='".$TEXT['aut-viewtit']."'><span class='zagolovok_vid'>".$result_body_book['book_name']."</span></a>";}
               else {$book_name = "<a href='../info.php?book_id=".$result_body_book['book_id']."' target='_blank' title='".$TEXT['aut-viewtit']."'><span class='zagolovok'>".$result_body_book['book_name']."</span></a>&nbsp;&nbsp;<a href=book-add-ccl.php?book_id=".$result_body_book['book_id']."&amp;cicle_id=".$old_ccl." title='".$TEXT['add-new']."'><img alt='".$TEXT['add-new']."' src='../skins/".$result2['skin']."/add.png' /></a>";}
               
               echo "<tr>";
               echo "<td colspan='2' align='center' width='50%'>".$book_name."</td>";
               echo "</tr>";
             }
         }
?>
</tbody>
</table>
     <?php
       $query_count = mysqli_query($dbcnx,"SELECT COUNT(book_id) AS c_book_id FROM tbl_book WHERE `first_bt` = '".$_GET['bukva']."' AND cicle_id = ".$ccl."");
	       $coun_rows = mysqli_fetch_array($query_count);
               $pag = $coun_rows['c_book_id']/10;
               if($pag<=1) {$pag = ceil($pag);}
                else
                {
                 ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='book-add-frm.php?k=".$k."&amp;bukva=".$_GET['bukva']."&amp;cicle_id=".$old_ccl."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='book-add-frm.php?k=".$k."&amp;bukva=".$_GET['bukva']."&amp;cicle_id=".$old_ccl."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=book-add-frm.php?k=".$k."&amp;bukva=".$_GET['bukva']."&amp;cicle_id=".$old_ccl.">".$j."</option>";}
                       else {echo "<option value=book-add-frm.php?k=".$k."&amp;bukva=".$_GET['bukva']."&amp;cicle_id=".$old_ccl.">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>
                 <?php
                }
require_once "../utils/bottom_adm.php";
?>
